@@ -1,5 +1,5 @@
-`H_delta` <-
-function(u, delta) {
+H_delta <-
+function(u, delta = 0) {
 if (delta ==0) return(u)
 1/delta*H(u*delta)
 }
