@@ -1,5 +1,5 @@
-`W_delta` <-
-function(z, delta) {
+W_delta <-
+function(z, delta = 0) {
 if (delta ==0) return(z) 
 W(delta*z)/delta
 }
