@@ -1,5 +1,5 @@
-`W_delta_1` <-
-function(z, delta) {
+W_delta_1 <-
+function(z, delta = 0) {
 if (delta ==0) return(z) 
 W_1(delta*z)/delta
 }
