@@ -1,18 +1,21 @@
 get.input <-
-function(y, theta) {
+function(y, theta, return.u=FALSE) {
 delta=theta[1]
 c=theta[2]
 s=theta[3]
 nu=theta[4]
 
 z=(y-c)/s
-u=1/delta*W(delta*z)
+u=W_delta(z, delta)
 x=u*s+c
 
+if (return.u)  {
 if (!is.na(nu)) u=sqrt(nu/(nu-2))*u
 O=NULL
 O$u=u
 O$x=x
 return(O)
 }
+else return(x)
+}
 
